<?php
/**
 * @file
 * Utility functions used in the classified module both at install and runtime
 *
 * @copyright (c) 2010-2011 Ouest Systemes Informatiques (OSInet)
 *
 * @license General Public License version 2 or later
 *
 * New code implementing a feature set derived from the ed_classified module.
 *
 * ---- Information about ed_classified ----
 * Michael Curry, Exodus Development, Inc.
 * exodusdev@gmail.com
 * for more information, please visit http://exodusdev.com/drupal/modules/ed_classified.module
 *
 * Copyright (c) 2006, 2007 Exodus Development, Inc.  All Rights Reserved.
 *
 * Licensed under the terms of the GNU Public License (GPL) version 2.  Please
 * see LICENSE.txt for license terms.  Possession and use of this code signifies
 * acceptance of license terms.
 * ---- /ed-classified ----
 */

/**
 * List the module variables.
 *
 * This is a first step towards D8 hook_variable_info().
 * @link http://drupal.org/node/145164 @endlink
 *
 * No static cache: there is no reason for this function to be invoked multiple
 * times on a page.
 *
 * @return array
 *   A hash of the variables and their defaults
 */
function _classified_get_vars() {
  $vars = array(
    'vid' => 0,
    'max-length' => 500,
    'list-body' => 'empty',
    'date-format' => t('%d/%m/%Y'),
    'lifetimes' => array(0 => 2 * 7), // 2 weeks lifetime
    'grace' => 7, // 1 week grace after expiration

    'recent-count' => 5,
    'popular-count' => 5,
    'edit-modr8' => TRUE, // editing a node sends it back to moderation (modr8) if available

    // Optional classified_notifications module
    'notifications-half-life-subject' => t('Classified Ad on [site-name]: half-life warning.'),
    'notifications-half-life-body' => t("Some of your Classified Ads on [site-name] have reached half their lifetime. They are listed below for your convenience.\n\nPlease visit your ads list at [classified-ads-url] if you wish to modify them.\n\n[ads]\n"),
    'notifications-pre-expire-subject' => t('Classified Ad on [site-name]: pre-expiration warning.'),
    'notifications-pre-expire-body' => t("Some of your Classified Ads on [site-name] will expire tomorrow. They are listed below for your convenience.\n\nPlease visit your ads list at [classified-ads-url] if you wish to extend their lifetime.\n\n[ads]\n"),
    'notifications-expire-subject' => t('Classified Ad expiration on [site-name] warning.'),
    'notifications-expire-body' => t("Some of your Classified Ads on [site-name] have expired. They are listed below for your convenience.\n\nPlease visit your ads list at [classified-ads-url] if you wish to renew them.\n\n[ads]\n"),
    'notifications-pre-purge-subject' => t('Classified Ad on [site-name]: pre-purge warning.'),
    'notifications-pre-purge-body' => t("Some of your expired Classified Ads on [site-name] will be deleted tomorrow. They are listed below for your convenience.\n\nPlease visit your ads list at [classified-ads-url] if you wish to avoid their deletion.\n\n[ads]\n"),
    'notifications-purge-subject' => t('Classified Ad purge on [site-name] warning.'),
    'notifications-purge-body' => t("Some of your expired Classified Ads on [site-name] have been purged. They are listed below for your convenience.\n\nPlease visit your ads list at [classified-ads-url] to check your remaining ads.\n\n[ads]\n"),
  );

  $ret = array();
  foreach ($vars as $name => $default) {
    $ret['classified-' . $name] = $default;
  }
  return $ret;
}

/**
 * A simplified alternative to variable_get().
 *
 * Prepends the name of the module and a dash, and automatically obtains the
 * default value if needed, as expected for D8.
 *
 * @param string $name
 *   The name of the variable to return.
 * @return mixed
 */
function _classified_get($name) {
  $vars = _classified_get_vars();
  $name = 'classified-' . $name;
  return variable_get($name, $vars[$name]);
}